      subroutine sindex2b(xpar,xmed,xstd1,xstd2,tlow,tup,delog,iw)
C......................................................................Feb. 2015
C
C Procedure to calculate Ionospheric Weather Storm S-index exceeding STD by +-10%
C
C
C   Input: xpar = NeF2  - instantaneous value of the F2 layer peak electron density 
C      or  xpar = foF2  - instantaneous value of the F2 layer critical frequency
C      or  xpar = hmF2  - instantaneous value of the F2 layer peak height 
C      or  xpar = TECi  - instantaneous value of GPS-derived total electron content
C      or  xpar = TECeff  - instantaneous value of GPS-derived spherical total electron content
C xmed = relevant quiet reference (-7 days median) value of any above parameter
C xstd1 - positive standard deviation of -15 days interval parameters from xmed for fixed location and time UT
C xstd2 - negative standard deviation of -15 days interval parameters from xmed for fixed location and time UT
C
C   Output: ionospheric weather S index characterizing ionospheric and plasmaspheric activity:
C           S = 0, +1 or -1 (quiet state)
C           S = +2 or -2 (moderate disturbance)
C           S = +3 or -3 (moderate storm)
C           S = +4 or -4 (intense storm)
C		  Bup - positive storm threshold = log10((xmed+std*1.1)/xmed)
C		  Blow - negative storm threshold = log10((xmed-std*1.1)/xmed)
C           dlog = log10(xpar/xmed)   
C
C   Includes logarithmic scale indices -4,-3,-2,-1,0,1,2,3,4
C   according to thresholds of dlog:
C NO!!!!!    log10(xpar/xmed)=-0.999,-0.301,-0.155,-0.045,0,0.045,0.155,0.301,0.999  
C
C Wx new derivation with dynamic thresholds
C Tpos=(xmax+xmed)/2; Tneg=(xmin+xmed)/2; Dlog=alog10(xpar/xmed)'
C Thresholds: 
C                 S_4 = -4 ~ Dlog < 2.0*alog10(1.-1.1*std/xmed)
C                 S_3 = -3 ~ 2.0*alog10(1.-1.1*std/xmed) =< Dlog < alog10(1.-1.1*std/xmed)
C                 S_2 = -2 ~  alog10(1.-1.1*std/xmed) < Dlog =<  0.5*alog10(1.-1.1*std/xmed)
C                 S_1 = -1 ~ 0.5*alog10(1.-1.1*std/xmed) < Dlog < 0
C                 S0 =  0 Dlog=0
C                 S1 =  1 ~ 0 < Dlog =< 0.5*alog10(1.+1.1*std/xmed)
C                 S2 =  2 ~  0.5*alog10(1.+1.1*std/xmed) < Dlog =<  alog10(1.+1.1*std/xmed)
C                 S3 =  3 ~  alog10(1.+1.1*std/xmed) < Dlog =<  2.0*alog10(1.+1.1*std/xmed)
C                 S4 =  4 ~ Dlog > 2.0*alog10(1.+1.1*std/xmed)
C
C   Dynamic thresholds: 
C
      DIMENSION TR(7)
	real xpar,xmed
	INTEGER IIN(7)
   		data IIN/-3,-2,-1,0,1,2,3/           ! ID-index
C	data TR/-.301,-.155,-.045,0.0
C	+,.045,.155,.301/
	
C 
	x1=alog10(xpar)
	x2=alog10(xmed)
	delog=x1-x2
C
C Specify dynamic thresholds by introducing weight:
C xweight=alog10(1.0+xstd/xmed) to S-index thresholds:
C Specify dynamic thresholds:
C?	tp2=1.1*(1.0+xstd2/xmed)
Crem	tp2=1.0+xstd2/xmed
	atp2=0.155*exp(-xstd2/xmed)
C?	tn2=1.1*(1.0-xstd/xmed)
Crem	tn2=1.0-xstd1/xmed*1.2
C?	if (tn2.le.0.0) tn2=0.70  !-30% threshold for negative storm if xstd>xmed
Crem	atn2=alog10(tn2)
	atn2=-0.155*exp(-xstd1/xmed)
	TR(2)=atn2  ! 
	TR(1)=TR(2)*2.0
	TR(3)=TR(2)/2.0
	TR(4)=0.0
	TR(6)=atp2  ! 
	TR(5)=TR(6)/2.0
	TR(7)=TR(6)*2.0
	TUP=TR(6)
	TLOW=TR(2)
   5		if (delog.eq.0.) then
			iw=0
	goto 2
	endif
	      if(delog.le.tr(1)) then
	iw=-4                 ! W-index
	goto 2
	endif
	if (delog.ge.tr(7)) then
	iw=4				  ! W-index
 	goto 2
	endif
C
	do 1 n=1,7
	if (delog.lt.0.) then
	if ((delog.ge.tr(n)).and.(delog.lt.tr(n+1))) then
	iw=iin(n)              ! W-index
	endif
	      else
	if ((delog.gt.tr(n-1)).and.(delog.le.tr(n))) then
	iw=iin(n)              ! W-index
	endif

	endif
   1	continue
C
   2  continue
C
	RETURN
	END
C
C
C ===============================================================
