      subroutine subsindex(xpar,xmed,rstd,tlow,tup,delog,iw)
C......................................................................Feb. 2015
C
C Procedure to calculate Ionospheric Weather Effective Wx index
C
C
C   Input: xpar = NeF2  - instantaneous value of the F2 layer peak electron density 
C      or  xpar = foF2  - instantaneous value of the F2 layer critical frequency
C      or  xpar = hmF2  - instantaneous value of the F2 layer peak height 
C      or  xpar = TECi  - instantaneous value of GPS-derived total electron content
C      or  xpar = TECeff  - instantaneous value of GPS-derived spherical total electron content
C xmed = relevant quiet reference (-7 days median) value of any above parameter
C rstd - standard deviation of -7 days interval parameters from xmed for given location and time
C
C   Output: ionospheric weather Wx index characterizing ionospheric and plasmaspheric activity:
C           Wx = 0, +1 or -1 (quiet state)
C           Wx = +2 or -2 (moderate disturbance)
C           Wx = +3 or -3 (moderate storm)
C           Wx = +4 or -4 (intense storm)
C		  Tup - positive storm threshold = log10((xmed+std)/xmed)
C		  Tlow - negative storm threshold = log10((xmed-std)/xmed)
C           dlog = log10(xpar/xmed)   
C
C   Includes logarithmic scale indices -4,-3,-2,-1,0,1,2,3,4
C   according to thresholds of dlog:
C NO!!!!!    log10(xpar/xmed)=-0.999,-0.301,-0.155,-0.045,0,0.045,0.155,0.301,0.999  
C
C Wx new derivation with dynamic thresholds
C Tpos=(xmax+xmed)/2; Tneg=(xmin+xmed)/2; Dlog=alog10(xpar/xmed)'
C Thresholds: 
C                 Wx = -4 ~ Dlog < alog10((xed-1.5*std)/xmed)
C                 Wx = -3 ~ alog10((xmed-1.5*std)/xmed) =< Dlog < alog10((xmed-std)/xmed)
C                 Wx = -2 ~ alog10((xmed-std)/xmed) < Dlog =< alog10((xmed-0.5*std)/xmed)
C                 Wx = -1 ~ alog10((xmed-0.5*std)/xmed) < Dlog < 0
C                 Wx =  0 Dlog=0
C                 Wx =  1 ~ 0 < Dlog =< alog10((xmed+0.5*std)/xmed)
C                 Wx =  2 ~ alog10((xmed+0.5*std)/xmed) < Dlog =< alog10((xmed+std)/xmed)
C                 Wx =  3 ~ alog10((xmed+std)/xmed) < Dlog =< alog10((xmed+1.5*std)/xmed)
C                 Wx =  4 ~ Dlog > alog10((xmed+1.5*std)/xmed)
C
C   Dynamic thresholds: 
C
      DIMENSION TR(7)
	real xpar,xmed
	INTEGER IIN(7)
   		data IIN/-3,-2,-1,0,1,2,3/           ! ID-index
C	data TR/-.301,-.155,-.045,0.0
C	+,.045,.155,.301/
C 
	x1=alog10(xpar)
	x2=alog10(xmed)
	delog=x1-x2
C
C Put limit on xstd for Wx negative:
	xstd=rstd
C??	if (xstd.ge.xmed*0.3) xstd=xmed*0.7
C Specify dynamic thresholds:
C+	tp1=(xmed+0.5*std)/xmed
C??	tp1=1.0+0.5*std/xmed
C??	tn1=1.0-0.5*xstd/xmed
C+    tp2=(xmed+std)/xmed
	tp2=1.0+rstd/xmed
	tn2=1.0-xstd/xmed
	if (tn2.le.0.7) tn2=0.7   ! -30% ~ threshold for storm
C
C Thresholds:
C
	TR(2)=alog10(tn2)
	TR(1)=TR(2)*2.0
	TR(3)=TR(2)/2.0
C
	TR(4)=0.0
C
	TR(6)=alog10(tp2)
	TR(5)=TR(6)/2.0
	TR(7)=TR(6)*2.0
	TUP=TR(6)
	TLOW=TR(2)
   5		if (delog.eq.0.) then
			iw=0
	goto 2
	endif
	      if(delog.le.tr(1)) then
	iw=-4                 ! S-index
	goto 2
	endif
	if (delog.ge.tr(7)) then
	iw=4				  ! S-index
 	goto 2
	endif
C
	do 1 n=1,7
	if (delog.lt.0.) then
	if ((delog.ge.tr(n)).and.(delog.lt.tr(n+1))) then
	iw=iin(n)              ! S-index
	endif
	      else
	if ((delog.gt.tr(n-1)).and.(delog.le.tr(n))) then
	iw=iin(n)              ! S-index
	endif

	endif
   1	continue
C
   2  continue
C
	RETURN
	END
C
C
C ===============================================================
